#
# spec file for package foma
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?make_build:%global make_build make %{?_smp_mflags}}
%define libname	libfoma0
Name:           foma
Version:        0.10.0+git22
Release:        1.4
Summary:        Finite-state compiler and C library
License:        Apache-2.0
URL:            https://fomafst.github.io/
Source:         foma-%version.tar.xz
BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  flex
BuildRequires:  ncurses-devel
BuildRequires:  pkg-config
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(zlib)

%description
Foma is a compiler, programming language, and C library for constructing
finite-state automata and transducers for various uses. It has specific support
for many natural language processing applications such as producing
morphological analyzers. Although NLP applications are probably the main use of
foma, it is sufficiently generic to use for a large number of purposes.

%package -n %{libname}
Summary:        Finite-state C library

%description -n %{libname}
The library contains efficient implementations of all classical
automata/transducer algorithms: determinization, minimization, epsilon-removal,
composition, boolean operations. Also, more advanced construction methods are
available: context restriction, quotients, first-order regular logic,
transducers from replacement rules, etc.

%package devel
Summary:        Finite-state C library development files and headers
Requires:       %{libname} = %{version}

%description devel
Finite-state C library development files and headers for %{name}.

%prep
%autosetup -p1

%build
pushd foma/
%cmake
%cmake_build
popd

%install
pushd foma/
%cmake_install
popd
find "%buildroot" -type f -name "*.a" -print -delete

%ldconfig_scriptlets -n %libname

%files
%{_bindir}/cgflookup
%{_bindir}/flookup
%{_bindir}/foma

%files devel
%{_includedir}/fomalib.h
%{_includedir}/fomalibconf.h
%{_libdir}/libfoma.so
%{_libdir}/pkgconfig/libfoma.pc

%files -n %{libname}
%license foma/COPYING
%{_libdir}/libfoma.so.*

%changelog
* Fri May 17 2024 Jan Engelhardt <jengelh@inai.de>
- Update to git snapshot 0.10.0+git22 (e0d8122)
  * Build fixes for various compilers and C++ standard modes
- Drop foma-gcc14.patch (merged), delete foma-harden-build.patch
  (obsolete)
* Mon May 13 2024 pgajdos@suse.com
- added patches
  fix https://github.com/mhulden/foma/commit/9a99d2d41809422080606bb49531b38ce1e2111a
  + foma-gcc14.patch
* Sat Aug 27 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.10.0
  * Add runtime options interface.
  * Fix numerous memory leaks and segfaults.
  * Skip flags elimination if there are no paths in network.
  * Fixed syntax error reporting line count in lexc.
  * Add Python 3 compatibility and Python 3 port of foma2js.perl.
  * Sort alphabet after eliminating flags.
* Sat Jun 26 2021 jengelh@inai.de
- Update to version 0.9.18+git20210604.180b6fe:
  * Drop xx prefix for standard C functions.
  * Add runtime options interface for HFST.
  * Fix segfault when Foma sigmas are merged.
  * Add test for leaks and segfaults to avoid regression.
  * Fix a premature free() call in fsm_isempty.
  * add ^> to lexc's regex lexer.
  * Fix memory leak in regex parser: destroy FSM via bison destructor.
  * Fix memory leaks in "print shortest-string" command processor.
  * Drop leftover command "test star-free"
  * Avoid memory leaks in test functions: free temporary FSMs after use.
  * Avoid memory leak in fsm_isempty function: release minimized FSM.
  * Avoid memory leak in fsm_rewrite: free center FSM after usage.
  * Skip definition without network when save_defined is executed.
* Wed May 19 2021 Fridrich Strba <fstrba@suse.com>
- Define conditionally make_build to fix build on systems that do
  not have that macro
* Mon Mar  2 2020 tchvatal@suse.com
- Update to version 0.9.18+git20200221.5e5521e bsc#1160265:
  * Ignore dylibs
  * Removed dependency on six
  * Bugfixes for Python
  * Added Python 3 port of foma2js.perl
  * Better py3 compatibility
  * Add test for apply_down().
  * Get apply_up() working.
  * Add simple Python tests.
  * Port FST.encode() to use correct types for Python 3.
  * Add Python six 1.11.0 module.
  * Added TextWrangler codeless language modules.
  * add object files and many temp files to .gitignore
  * remove SVN_REV var in Makefile
- Remove upstream merged patch:
  * foma-fix-sizeof.patch
* Thu Sep 27 2018 Bernhard Wiedemann <bwiedemann@suse.com>
- Add foma-fix-sizeof.patch to fix segfault on 32-bit (boo#1109949)
* Thu Sep 27 2018 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to add some linker hardening:
  * foma-harden-build.patch
* Thu Sep 27 2018 tchvatal@suse.com
- Update to version 0.9.18+git20180511.bad2f09:
  * Various small fixes
* Wed May 17 2017 tchvatal@suse.com
- Build in single thread, interim deps are not properly stated in
  the Makefile
* Wed May 17 2017 tchvatal@suse.com
- Update to version 0.9.18+git20170507.07bb944:
  * Switch to git snapshot to ensure license to be correctly set
  * Install COPYING
* Wed Apr 26 2017 tchvatal@suse.com
- Initial commit required by malaga-suomi
- Taken from Mageia
